'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var cn = require('classnames');
var coreComponentsTypography = require('@alfalab/core-components-typography');
var const_progressBar = require('../../../../const/progress-bar.js');
var context_fileUploadItemContext = require('../../../../context/file-upload-item-context.js');
var utils = require('../../../../utils.js');
var components_content_utils_isError = require('../../utils/isError.js');
var components_content_components_contentError_contentError = require('../content-error/content-error.js');

function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e : { default: e }; }

var React__default = /*#__PURE__*/_interopDefaultCompat(React);
var cn__default = /*#__PURE__*/_interopDefaultCompat(cn);

var styles = {"subtitle":"file-upload-item__subtitle_lisnx","truncate":"file-upload-item__truncate_lisnx","size":"file-upload-item__size_lisnx"};
require('./content-subtitle.css')

var ContentSubtitle = function () {
    var _a;
    var _b = React.useContext(context_fileUploadItemContext.FileUploadItemContext), uploadStatus = _b.uploadStatus, subtitle = _b.subtitle, uploadDate = _b.uploadDate, size = _b.size, truncate = _b.truncate, showRestore = _b.showRestore, error = _b.error, progressBar = _b.progressBar;
    var shouldShownError = utils.isErrorStatus(uploadStatus) || components_content_utils_isError.isError(error);
    var showMeta = !showRestore && (utils.isSuccessStatus(uploadStatus) || utils.isUploadedStatus(uploadStatus));
    // валидация progressBar (не должен превышать 100 и быть меньше 0)
    var validateProgressBarValue = function (progressValue) {
        if (progressValue === undefined) {
            return 0;
        }
        return Math.min(Math.max(progressValue, 0), const_progressBar.MAX_PROGRESS_BAR_VALUE);
    };
    var validProgressBar = validateProgressBarValue(progressBar);
    // uploading status
    if (utils.isUploadingStatus(uploadStatus)) {
        return (React__default.default.createElement(coreComponentsTypography.Text, { view: 'primary-small', color: 'secondary' },
            "\u0417\u0430\u0433\u0440\u0443\u0437\u043A\u0430",
            '\u00A0',
            Math.floor(validProgressBar),
            "%"));
    }
    // error status
    if (shouldShownError) {
        return React__default.default.createElement(components_content_components_contentError_contentError.ContentError, null);
    }
    // success status
    if (showMeta) {
        return (React__default.default.createElement("div", null,
            size && (React__default.default.createElement(coreComponentsTypography.Text, { className: styles.size, view: 'primary-small', color: 'secondary' }, utils.humanFileSize(size))),
            uploadDate && (React__default.default.createElement(coreComponentsTypography.Text, { view: 'primary-small', color: 'secondary' }, uploadDate))));
    }
    // restore status
    if (showRestore) {
        return (React__default.default.createElement(coreComponentsTypography.Text, { view: 'primary-small', color: 'tertiary' }, "\u0424\u0430\u0439\u043B \u0443\u0434\u0430\u043B\u0435\u043D"));
    }
    return (React__default.default.createElement(coreComponentsTypography.Text, { className: cn__default.default(styles.subtitle, (_a = {},
            _a[styles.truncate] = truncate,
            _a)), view: 'primary-small', color: 'secondary' }, subtitle));
};

exports.ContentSubtitle = ContentSubtitle;
