import React, { useContext } from 'react';
import cn from 'classnames';
import { Document1CMIcon } from '@alfalab/icons-glyph/Document1CMIcon';
import { DocumentDocMIcon } from '@alfalab/icons-glyph/DocumentDocMIcon';
import { DocumentExcelMIcon } from '@alfalab/icons-glyph/DocumentExcelMIcon';
import { DocumentImageMIcon } from '@alfalab/icons-glyph/DocumentImageMIcon';
import { DocumentMIcon } from '@alfalab/icons-glyph/DocumentMIcon';
import DocumentOffMIcon from '@alfalab/icons-glyph/DocumentOffMIcon';
import { DocumentPdfMIcon } from '@alfalab/icons-glyph/DocumentPdfMIcon';
import { PaperclipMIcon } from '@alfalab/icons-glyph/PaperclipMIcon';
import { FileUploadItemContext } from '../../../../context/file-upload-item-context.js';
import { isInitialStatus, getExtension } from '../../../../utils.js';

const styles = {"iconPDFColored":"file-upload-item__iconPDFColored_jnzv2","iconDOCColored":"file-upload-item__iconDOCColored_jnzv2","iconExcelColored":"file-upload-item__iconExcelColored_jnzv2","icon1CColored":"file-upload-item__icon1CColored_jnzv2","iconDocumentColored":"file-upload-item__iconDocumentColored_jnzv2"};
require('./status-control-icon.css')

/* eslint-disable complexity */
const StatusControlIcon = () => {
    const { title = '', uploadStatus, iconStyle, customIcon: CustomIcon, imageUrl, showRestore, } = useContext(FileUploadItemContext);
    if (imageUrl) {
        return null;
    }
    if (CustomIcon) {
        return React.createElement(CustomIcon, null);
    }
    if (isInitialStatus(uploadStatus)) {
        return React.createElement(PaperclipMIcon, null);
    }
    if (showRestore) {
        return React.createElement(DocumentOffMIcon, null);
    }
    const isColoredIcon = iconStyle === 'colored';
    const fileType = getExtension(title);
    switch (fileType) {
        case 'pdf':
        case 'ppt':
        case 'pptx':
            return React.createElement(DocumentPdfMIcon, { className: cn({ [styles.iconPDFColored]: isColoredIcon }) });
        case 'doc':
        case 'docx':
            return React.createElement(DocumentDocMIcon, { className: cn({ [styles.iconDOCColored]: isColoredIcon }) });
        case 'xls':
        case 'xlsx':
            return (React.createElement(DocumentExcelMIcon, { className: cn({ [styles.iconExcelColored]: isColoredIcon }) }));
        case '1c':
            return React.createElement(Document1CMIcon, { className: cn({ [styles.icon1CColored]: isColoredIcon }) });
        case 'png':
        case 'jpg':
        case 'jpeg':
        case 'svg':
        case 'tif':
        case 'tiff':
            return React.createElement(DocumentImageMIcon, null);
        default:
            return (React.createElement(DocumentMIcon, { className: cn({ [styles.iconDocumentColored]: isColoredIcon }) }));
    }
};

export { StatusControlIcon };
